@@ -3,7 +3,7 @@ import numpy as np
 import torch
 
 
-def plot_true_prop_accept(z_target, z_accepted, z_proposal=None, acceptance_logprobs=None, **kwargs):
+def plot_true_prop_accept(z_target=None, z_accepted=None, z_proposal=None, acceptance_logprobs=None, **kwargs):
     '''
     Plots scatter plot with target points, proposal and accepted (scaled according to acceptance ratio if provided)
     :param z_target: target samples
@@ -21,15 +21,17 @@ def plot_true_prop_accept(z_target, z_accepted, z_proposal=None, acceptance_logp
 
     plt.figure(**kwargs)
 
-    z_target = z_target.cpu().detach().numpy()
-    plt.scatter(x=z_target[:, 0], y=z_target[:, 1], c='b', label='Target')
+    if z_target is not None:
+        z_target = z_target.cpu().detach().numpy()
+        plt.scatter(x=z_target[:, 0], y=z_target[:, 1], c='b', label='Target')
 
     if z_proposal is not None:
         z_proposal = z_proposal.cpu().detach().numpy()
         plt.scatter(x=z_proposal[:, 0], y=z_proposal[:, 1], c='r', label='Proposal')
 
-    z_accepted = z_accepted.cpu().detach().numpy()
-    plt.scatter(x=z_accepted[:, 0], y=z_accepted[:, 1], c='g', label='Accepted', s=acceptance_probs + 15)
+    if z_accepted is not None:
+        z_accepted = z_accepted.cpu().detach().numpy()
+        plt.scatter(x=z_accepted[:, 0], y=z_accepted[:, 1], c='g', label='Accepted', s=acceptance_probs + 15)
 
     plt.legend()
     plt.show()
